pygeodesy.geohash.Neighbors8Dict

Package pygeodesy :: Module geohash :: Class Neighbors8Dict |
[frames] | no frames]

# Class Neighbors8Dict

    object --+
             |
          dict --+
                 |
       named.ADict --+
                     |
        object --+   |
                 |   |
      named._Named --+
                     |
      named._NamedDict --+
                         |
                        Neighbors8Dict

8-Dict `(N, NE, E, SE, S, SW, W, NW)` of Geohashes, providing key and attribute access to the items.

Instance Methods
    new empty dictionary
__init__(self, **kwds) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `named._NamedDict`: `__delattr__`, `__getattr__`, `__getitem__`, `__setattr__`, `__setitem__` Inherited from `named.ADict`: `__repr__`, `__str__`, `set_`, `toRepr`, `toStr` Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__reduce__`, `__reduce_ex__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `named.ADict`: `iteration`, `typename` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof` Inherited from `object`: `__class__`

Method Details

### __init__ (self, **kwds) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)